import { Nullable, Buoy, Coords, FindBuoysParams } from "./types";
/**
 * getDistanceToBuoy - calculate the geographic distance between a given location and a specific buoy location using the haversine formula
 *
 * @param givenLocation - latitude and longitude of a given (starting) location
 * @param buoyLocation - latitude and longitude of a buoy to find the distance from
 */
declare const getDistanceToBuoy: ({ givenLocation, buoyLocation, units, }: {
    givenLocation: Coords;
    buoyLocation: Coords;
    units: string;
}) => number;
/**
 * findNearestBuoys - find the nearest number of buoys to a given location
 *
 * @param location - a given location to find buoys closest to
 * @param units - units of measurement
 * @param numBuoys - number of buoys to find (defaults to all)
 * @param stations - list of buoy stations to search against (defaults to all)
 */
declare const findNearestBuoys: ({ location, units, numBuoys, stations, }: Omit<FindBuoysParams, "onlyActiveBuoys">) => Nullable<Buoy | Buoy[]>;
export { getDistanceToBuoy, findNearestBuoys };
